@@ -1,8 +1,5 @@
 use super::*;
-use std::{
-    slice::Iter,
-};
-
+use std::slice::Iter;
 
 impl<T> LiteralVector<T> {
     /// Returns the number of elements in the vector, also referred to as its 'length'.
@@ -26,11 +23,11 @@ impl<T> LiteralVector<T> {
 }
 
 /// Wrapper type of [`LiteralPattern::iter`]
-pub struct LiteralPatternIter<'i,T> {
+pub struct LiteralPatternIter<'i, T> {
     inner: Iter<'i, Literal<T>>,
 }
 
-impl<'i,T> Iterator for LiteralPatternIter<'i,T>{
+impl<'i, T> Iterator for LiteralPatternIter<'i, T> {
     type Item = &'i T;
 
     fn next(&mut self) -> Option<Self::Item> {
